@@ -1,7 +1,7 @@
 """
 Type annotations for sagemaker-runtime service client.
 
-[Open documentation](./client.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html)
 
 Usage::
 
@@ -39,8 +39,8 @@ class Exceptions:
 
 class SageMakerRuntimeClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
-    [Show boto3-stubs documentation](./client.md)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html)
     """
 
     meta: ClientMeta
@@ -48,8 +48,8 @@ class SageMakerRuntimeClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html#can_paginate)
         """
 
     def generate_presigned_url(
@@ -60,12 +60,13 @@ class SageMakerRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html#generate_presigned_url)
         """
 
     def invoke_endpoint(
         self,
+        *,
         EndpointName: str,
         Body: Union[bytes, IO[bytes]],
         ContentType: str = None,
@@ -74,9 +75,9 @@ class SageMakerRuntimeClient:
         TargetModel: str = None,
         TargetVariant: str = None,
         TargetContainerHostname: str = None,
-        InferenceId: str = None,
+        InferenceId: str = None
     ) -> InvokeEndpointOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.75/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
-        [Show boto3-stubs documentation](./client.md#invoke_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html#invoke_endpoint)
         """
